/* global module: false, require: false */
'use strict';

const fs = require('fs');
const path = require('path');
const map = require('broccoli-stew').map;
const Funnel = require('broccoli-funnel');
const mergeTrees = require('broccoli-merge-trees');
const defaultsDeep = require('lodash.defaultsdeep');

module.exports = {
  name: 'ui-foundation',

  isDevelopingAddon() {
    return true;
  },

  included(parent) {
    this.options = defaultsDeep(parent.options, this.options);

    this._super.included.apply(this, arguments);

    if (this.options.useNormalizeCSS) {
      this.import('node_modules/normalize.css/normalize.css', {prepend: true});
    }

    if (this.options.useDeviceJS) {
      this.import('vendor/device.js/device.umd.js');
    }
  },

  treeForVendor(defaultTree) {
    if (this.options.useDeviceJS) {
      let deviceJSOpts = {srcDir: 'dist', include: ['device.umd.js'], destDir: 'device.js'};
      let wrapperFunc = content => `if (typeof FastBoot === 'undefined') {\n${content}\n`
          + `window.device = device.device; device.addClasses(document.documentElement);}`;
      let deviceJSTree = map(new Funnel('node_modules/device.js', deviceJSOpts), wrapperFunc);
      return new mergeTrees([defaultTree, deviceJSTree]);
    }

    return defaultTree;
  },

  contentFor(type, config, content) {
    switch (type) {
      case 'head-footer': return this._contentForHeadFooter.call(this, config, content);
      case 'body-footer': return this._contentForBodyFooter.call(this, config, content);
      default: return '';
    }
  },

  _contentForHeadFooter(/* config, content */) {
    let content = [];

    if (this.options.disableInspectorInProductionMode && this.app.env === 'production') {
      content.push(`<script>window.NO_EMBER_DEBUG = true;</script>`);
    }

    return content.join('\n');
  },

  _contentForBodyFooter(/* config, content */) {
    let content = [];

    if (this.options.importSVGIcon) {
      let basePath = this._basePathForProject(this.project);
      let filePath = path.resolve(basePath, `addon/${this.options.importSVGIcon}-icons.html`);
      content.push(fs.readFileSync(filePath, 'utf-8').replace(/\n\r?/g, ''));
    }

    return content.join('\n');
  },

  _basePathForProject({pkg, root, nodeModulesPath}) {
    return pkg.name.includes(this.name) ? root : path.join(nodeModulesPath, '@choiceform', this.name);
  },
};
